/*
 * selenium.js:
 *
 * (C) 2013 First Opinion
 * MIT LICENCE
 *
 */

var async = require('async'),
    spawn = require('./spawn-cmd').spawn,
    cmds  = require('./cmds');

//
// Module
//
var selenium = module.exports = {
  seleniumSrc: 'https://selenium.googlecode.com/files/selenium-server-standalone-2.35.0.jar',
  javaPkg: 'openjdk-7-jre-headless'
};

//
// Configure
//
selenium.configure = function (opts) {
    for (var key in opts) {
      selenium[key] = opts[key];
    }
};

//
// Install Selenium
//
selenium.install = function (next) {
  async.series([
    selenium.getJava,
    function (next) {
      console.log('DOWNLOADING SELENIUM');
      cmds.download({
        src: selenium.seleniumSrc,
        dest: '/var/lib/selenium'
      }, next);
    }
  ], next)
}

//
// Install java if not already installed
//
selenium.getJava = function (next) {
  console.log('CHECKING FOR JAVA');
  spawn('java', [
    '-version'
  ], function (err) {
    // If installed continue
    if (!err) { return next() }
    //  Else install
    console.log('JAVA NOT FOUND: INSTALLING');
    async.series([
      cmds.update,
      async.apply(cmds.install, {
        pkg: selenium.javaPkg
      })
    ], next);
  });
}

//
// Start selenium server
//
selenium.startServer = function () {
  var selSrcParts = selenium.seleniumSrc.split('/');
  console.log('STARTING SERVER');
  selenium.server = spawn('java', [
    '-jar',
    '/var/lib/selenium/' + selSrcParts[selSrcParts.length - 1]
  ], function (err) {
    if (err) { return console.log(err) }
  });
  console.log('==============');
  console.log('SERVER STARTED');
}

//
// Stop selenium server
//
selenium.stopServer = function () {
  selenium.server.kill();
}