/*
 * test/formatter.js:
 *
 * (C) 2013 First Opinion
 * MIT LICENCE
 *
 */

var selenium = require('../lib/selenium'),
    request  = require('request'),
    should   = require('chai').should(),
    assert   = require('chai').assert;

// Contstants used during tests
var JAVA_PKG = 'openjdk-7-jre-headless',
    SEL_SRC  = 'https://selenium.googlecode.com/files/selenium-server-standalone-2.35.0.jar',
    SRV_URL  = 'http://localhost:4444/selenium-server/driver?cmd=shutDownSeleniumServer';

//
// Test configure, install, and start methods
//
var testInstallStart = function(done){
  // Send request to SEL_SRC and check for response
  // the request is made to an endpoint that will shutdown
  // the server for us. Test and clean up :)
  var requestSelenium = function () {
    request(SRV_URL, function (err, res) {
      if (err) { return done(err) }
      return (res.statusCode == 200)
        ? done()
        : done(new Error('Incorrect Status Code'));
    });
  }
  // Make sure config does not throw errors. Using defaults
  selenium.configure({
    seleniumSrc: SEL_SRC,
    javaPkg: JAVA_PKG
  });
  // Install and start server
  selenium.install(function (err) {
    if (err) { return done(err) }
    // Start server.
    selenium.startServer();
    // Ugly setTimeout in order to wait for Server to launch.
    // Make request and check for response
    setTimeout(requestSelenium, 10000);
  });
}

//
// Run Tests
//
describe('selenium', function () {
  // Install will take a while
  this.timeout(500000);
  // Run
  it('should install and start server', testInstallStart);
});